#
# spec file for package python-npTDMS
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define         skip_python2 1
%define         skip_python36 1
Name:           python-npTDMS
Version:        1.2.0
Release:        1.10
Summary:        Python module for reading TDMS files produced by LabView
License:        LGPL-3.0-only
URL:            https://github.com/adamreeve/npTDMS
Source:         https://github.com/adamreeve/npTDMS/archive/%{version}.tar.gz#/npTDMS-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-numpy
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module numpy}
# /SECTION
%python_subpackages

%description
NumPy based module for reading TDMS files produced by LabView.

%prep
%setup -q -n npTDMS-%{version}

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/tdmsinfo
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%python_exec -B -m unittest discover -s nptdms -p "*_test.py"

%post
%python_install_alternative tdmsinfo

%postun
%python_uninstall_alternative tdmsinfo

%files %{python_files}
%doc README.rst
%license COPYING COPYING.LESSER
%python_alternative %{_bindir}/tdmsinfo
%{python_sitelib}/*

%changelog
* Thu Apr 22 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.2.0:
  * Reduce memory usage when reading files in open mode
  * Support files that use DAQmx format metadata without having DAQmx raw data
  * Support different lengths of DAQmx buffers
  * Support strain scaling with a full bridge type I configuration
  * Support negative integer indexing in channels
  * Improve performance reading many small interleaved data chunks
  * Breaking change: Remove previously deprecated methods
  * Correct the TDMS type used when writing floating point data
  * Fix reading digital line scaler data with a non-zero offset
  * Adds support for reading raw timestamps with full precision
  * Fixes memory leaks caused by circular references
  * Fix for reading tdms_index files with padding after metadata
  * Add support for negative temperatures with RTD scaling
  * Use tdms_index files when available
  * Support indexing and slicing channels
  * Support streaming data chunks
  * Support iterating over files, groups and channels
  * Deprecates many methods than will now warn when used
  * Fixes inconsistent behaviour when exporting to Pandas dataframes
- Do not build for Python 3.6, due to no NumPy.
* Thu May 21 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Thu Nov 21 2019 Todd R <toddrme2178@gmail.com>
- Initial version
